Mesa (master): mesa: fix aux/accum comment and error message mixups

Brian Paul brianp at kemper.freedesktop.org
Tue Nov 2 16:06:52 UTC 2010


Module: Mesa
Branch: master
Commit: fc70c05dbd5af94b04cf4717253cfbd57aadf1af
URL:    http://cgit.freedesktop.org/mesa/mesa/commit/?id=fc70c05dbd5af94b04cf4717253cfbd57aadf1af

Author: Brian Paul <brianp at vmware.com>
Date:   Tue Nov  2 09:56:04 2010 -0600

mesa: fix aux/accum comment and error message mixups

---

 src/mesa/main/renderbuffer.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/mesa/main/renderbuffer.c b/src/mesa/main/renderbuffer.c
index dc8bc74..3d1a8f8 100644
--- a/src/mesa/main/renderbuffer.c
+++ b/src/mesa/main/renderbuffer.c
@@ -1766,7 +1766,7 @@ _mesa_add_accum_renderbuffer(struct gl_context *ctx, struct gl_framebuffer *fb,
 
 
 /**
  * Add a software-based accumulation renderbuffer to the given framebuffer.
  * This is a helper routine for device drivers when creating a
  * window system framebuffer (not a user-created render/framebuffer).
  * Once this function is called, you can basically forget about this
@@ -1795,7 +1795,7 @@ _mesa_add_aux_renderbuffers(struct gl_context *ctx, struct gl_framebuffer *fb,
       assert(fb->Attachment[BUFFER_AUX0 + i].Renderbuffer == NULL);
 
       if (!rb) {
-         _mesa_error(ctx, GL_OUT_OF_MEMORY, "Allocating accum buffer");
+         _mesa_error(ctx, GL_OUT_OF_MEMORY, "Allocating aux buffer");
          return GL_FALSE;
       }
 
@@ -1766,7 +1766,7 @@ _mesa_add_accum_renderbuffer(struct gl_context *ctx, struct gl_framebuffer *fb,
 
 /**
- * Add a software-based accumulation renderbuffer to the given framebuffer.
+ * Add a software-based aux renderbuffer to the given framebuffer.
  * This is a helper routine for device drivers when creating a
  * window system framebuffer (not a user-created render/framebuffer).




More information about the mesa-commit mailing list